@@ -38,10 +38,11 @@
 #include <QtCore/QDateTime>
 #include <QtCore/QDate>
 #include <QtCore/QTime>
-#include <math.h>
+
 #include <QMetaType>
 #include <QDebug>
 #include <KLocale>
+#include <cmath>
 
 /**
  * \class AbstractColumn
@@ -213,7 +214,7 @@ void AbstractColumn::clear() {}
 bool AbstractColumn::isValid(int row) const {
 	switch (columnMode()) {
 		case AbstractColumn::Numeric:
-			return !isnan(valueAt(row));
+			return !std::isnan(valueAt(row));
 		case AbstractColumn::Text:
 			return !textAt(row).isNull();
 		case AbstractColumn::DateTime:
@@ -459,15 +460,14 @@ void AbstractColumn::setValueAt(int row, double new_value) {
  */
 void AbstractColumn::replaceValues(int first, const QVector<double>& new_values) {
 	Q_UNUSED(first) Q_UNUSED(new_values)
-};
-
+}
 
 double AbstractColumn::minimum() const{
 	double val;
 	double min = INFINITY;
 	for (int row = 0; row < rowCount(); row++) {
 		val = valueAt(row);
-		if (isnan(val))
+		if (std::isnan(val))
 			continue;
 
 		if (val < min)
@@ -481,7 +481,7 @@ double AbstractColumn::maximum() const{
 	double max = -INFINITY;
 	for (int row = 0; row < rowCount(); row++) {
 		val = valueAt(row);
-		if (isnan(val))
+		if (std::isnan(val))
 			continue;
 
 		if (val > max)
