@@ -1,10 +1,10 @@
 /***************************************************************************
-	File                 : MainWin.cc
-	Project              : LabPlot
-	Description          : Main window of the application
-	--------------------------------------------------------------------
-	Copyright            : (C) 2009-2015 Alexander Semke (alexander.semke@web.de)
-	Copyright            : (C) 2008-2015 Stefan Gerlach (stefan.gerlach@uni.kn)
+    File                 : MainWin.cc
+    Project              : LabPlot
+    Description          : Main window of the application
+    --------------------------------------------------------------------
+    Copyright            : (C) 2009-2015 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2008-2015 Stefan Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
 
@@ -37,14 +37,22 @@
 #include "backend/matrix/Matrix.h"
 #include "backend/worksheet/Worksheet.h"
 #include "backend/datasources/FileDataSource.h"
+#ifdef HAVE_CANTOR_LIBS
+#include "backend/cantorWorksheet/CantorWorksheet.h"
+#endif
 #include "backend/datapicker/Datapicker.h"
+#include "backend/note/Note.h"
 
 #include "commonfrontend/ProjectExplorer.h"
 #include "commonfrontend/matrix/MatrixView.h"
 #include "commonfrontend/spreadsheet/SpreadsheetView.h"
 #include "commonfrontend/worksheet/WorksheetView.h"
+#ifdef HAVE_CANTOR_LIBS
+#include "commonfrontend/cantorWorksheet/CantorWorksheetView.h"
+#endif
 #include "commonfrontend/datapicker/DatapickerView.h"
 #include "commonfrontend/datapicker/DatapickerImageView.h"
+#include "commonfrontend/note/NoteView.h"
 
 #include "kdefrontend/datasources/ImportFileDialog.h"
 #include "kdefrontend/dockwidgets/ProjectDock.h"
@@ -62,6 +70,7 @@
 #include <QMimeData>
 #include <QElapsedTimer>
 #include <QDebug>
+#include <QHash>
 
 #include <KActionCollection>
 #include <KFileDialog>
@@ -73,6 +82,10 @@
 #include <KLocalizedString>
 #include <KFilterDev>
 
+#ifdef HAVE_CANTOR_LIBS
+#include <cantor/backend.h>
+#endif
+
 /*!
 \class MainWin
 \brief Main application window.
@@ -96,6 +109,7 @@ MainWin::MainWin(QWidget *parent, const QString& filename)
 	  m_visibilityMenu(0),
 	  m_newMenu(0),
 	  axisDock(0),
+	  notesDock(0),
 	  cartesianPlotDock(0),
 	  cartesianPlotLegendDock(0),
 	  columnDock(0),
@@ -104,12 +118,19 @@ MainWin::MainWin(QWidget *parent, const QString& filename)
 	  projectDock(0),
 	  xyCurveDock(0),
 	  xyEquationCurveDock(0),
+	  xyInterpolationCurveDock(0),
+	  xySmoothCurveDock(0),
 	  xyFitCurveDock(0),
+	  xyFourierFilterCurveDock(0),
+	  xyFourierTransformCurveDock(0),
 	  worksheetDock(0),
 	  textLabelDock(0),
 	  customPointDock(0),
 	  datapickerImageDock(0),
 	  datapickerCurveDock(0),
+#ifdef HAVE_CANTOR_LIBS
+	cantorWorksheetDock(0),
+#endif
 	  m_guiObserver(0) {
 
 // 	QTimer::singleShot( 0, this, SLOT(initGUI(filename)) );  //TODO doesn't work anymore
@@ -147,11 +168,13 @@ void MainWin::initGUI(const QString& fileName) {
 	setCentralWidget(m_mdiArea);
 	connect(m_mdiArea, SIGNAL(subWindowActivated(QMdiSubWindow*)),
 	        this, SLOT(handleCurrentSubWindowChanged(QMdiSubWindow*)));
-
+#ifdef _WIN32
+	QIcon::setThemeName("hicolor");
+#endif
 	statusBar()->showMessage(i18nc("%1 is the LabPlot version", "Welcome to LabPlot %1", QLatin1String(LVERSION)));
 	initActions();
+	setupGUI(Default, QLatin1String("labplot2ui.rc"));
 	initMenus();
-	setupGUI();
 	setWindowIcon(QIcon::fromTheme("LabPlot2"));
 	setAttribute( Qt::WA_DeleteOnClose );
 
@@ -243,6 +266,10 @@ void MainWin::initActions() {
 // 	m_newWorksheetAction->setShortcut(Qt::ALT+Qt::Key_X);
 	actionCollection()->addAction("new_worksheet", m_newWorksheetAction);
 	connect(m_newWorksheetAction, SIGNAL(triggered()), SLOT(newWorksheet()));
+	
+	m_newNotesAction= new QAction(QIcon::fromTheme("document-new"),i18n("Note"),this);
+	actionCollection()->addAction("new_notes", m_newNotesAction);
+	connect(m_newNotesAction, SIGNAL(triggered()), SLOT(newNotes()));
 
 // 	m_newScriptAction = new QAction(QIcon::fromTheme("insert-text"),i18n("Note/Script"),this);
 // 	actionCollection()->addAction("new_script", m_newScriptAction);
@@ -282,13 +309,13 @@ void MainWin::initActions() {
 	connect(m_historyAction, SIGNAL(triggered()),SLOT(historyDialog()));
 
 	// Appearance
-	// Analysis
+	// Analysis: see WorksheetView.cpp
 	// Drawing
 	// Script
 
 	//Windows
 	action  = new QAction(i18n("Cl&ose"), this);
-	actionCollection()->setDefaultShortcut(action, i18n("Ctrl+W"));
+	actionCollection()->setDefaultShortcut(action, Qt::CTRL+Qt::Key_W);
 	action->setStatusTip(i18n("Close the active window"));
 	actionCollection()->addAction("close window", action);
 	connect(action, SIGNAL(triggered()), m_mdiArea, SLOT(closeActiveSubWindow()));
@@ -365,9 +392,45 @@ void MainWin::initMenus() {
 	m_newMenu->addAction(m_newSpreadsheetAction);
 	m_newMenu->addAction(m_newMatrixAction);
 	m_newMenu->addAction(m_newWorksheetAction);
+	m_newMenu->addAction(m_newNotesAction);
 	m_newMenu->addAction(m_newDatapickerAction);
 	m_newMenu->addSeparator();
 	m_newMenu->addAction(m_newFileDataSourceAction);
+
+#ifdef HAVE_CANTOR_LIBS
+	m_newMenu->addSeparator();
+	//"Adding Cantor backends to menue and context menu"
+	QStringList m_availableBackend = Cantor::Backend::listAvailableBackends();
+	if(m_availableBackend.count() > 0) {
+		m_newCantorWorksheetMenu = new QMenu(i18n("CAS Worksheet"));
+		m_newCantorWorksheetMenu->setIcon(QIcon::fromTheme("archive-insert"));
+		unplugActionList(QLatin1String("backends_list"));
+		QList<QAction*> newBackendActions;
+		foreach (Cantor::Backend* backend, Cantor::Backend::availableBackends()) {
+			if (!backend->isEnabled()) continue;
+			QAction* action = new QAction(QIcon::fromTheme(backend->icon()), backend->name(),this);
+			action->setData(backend->name());
+			newBackendActions << action;
+			m_newCantorWorksheetMenu->addAction(action);
+		}
+
+		connect(m_newCantorWorksheetMenu, SIGNAL(triggered(QAction*)), this, SLOT(newCantorWorksheet(QAction*)));
+		plugActionList(QLatin1String("backends_list"), newBackendActions);
+		m_newMenu->addMenu(m_newCantorWorksheetMenu);
+	} else {
+		int choice = KMessageBox::warningContinueCancel(this, i18n("No backend for Cantor is installed."), i18n("Warning"));
+		switch(choice) {
+			case KMessageBox::Cancel:
+			close();
+			break;
+		}
+	}
+#else
+	delete this->guiFactory()->container("cas_worksheet", this);
+	delete this->guiFactory()->container("new_casWorksheet", this);
+	delete this->guiFactory()->container("cas_worksheet_toolbar", this);
+#endif
+
 // 	m_newMenu->addAction(m_newSqlDataSourceAction);
 
 	//menu subwindow visibility policy
@@ -383,7 +446,7 @@ void MainWin::initMenus() {
 	\return \c true if the project still needs to be saved ("cancel" clicked), \c false otherwise.
  */
 bool MainWin::warnModified() {
-	if(m_project->hasChanged()) {
+	if (m_project->hasChanged()) {
 		int want_save = KMessageBox::warningYesNoCancel( this,
 		                i18n("The current project %1 has been modified. Do you want to save it?", m_project->name()),
 		                i18n("Save Project"));
@@ -433,14 +496,19 @@ void MainWin::updateGUIOnProjectChanges() {
 	m_togglePropertiesDockAction->setEnabled(!b);
 
 	if (!m_mdiArea->currentSubWindow()) {
-		factory->container("worksheet", this)->setEnabled(false);
 		factory->container("spreadsheet", this)->setEnabled(false);
-		factory->container("datapicker", this)->setEnabled(false);
 		factory->container("matrix", this)->setEnabled(false);
+		factory->container("worksheet", this)->setEnabled(false);
+		factory->container("analysis", this)->setEnabled(false);
+		factory->container("datapicker", this)->setEnabled(false);
+		factory->container("spreadsheet_toolbar", this)->hide();
 		factory->container("worksheet_toolbar", this)->hide();
 		factory->container("cartesian_plot_toolbar", this)->hide();
-		factory->container("spreadsheet_toolbar", this)->hide();
 		factory->container("datapicker_toolbar", this)->hide();
+#ifdef HAVE_CANTOR_LIBS
+		factory->container("cas_worksheet", this)->setEnabled(false);
+		factory->container("cas_worksheet_toolbar", this)->hide();
+#endif
 	}
 
 	factory->container("new", this)->setEnabled(!b);
@@ -472,14 +540,19 @@ void MainWin::updateGUI() {
 	}
 
 	if (!m_mdiArea->currentSubWindow()) {
-		factory->container("worksheet", this)->setEnabled(false);
 		factory->container("spreadsheet", this)->setEnabled(false);
-		factory->container("datapicker", this)->setEnabled(false);
 		factory->container("matrix", this)->setEnabled(false);
+		factory->container("worksheet", this)->setEnabled(false);
+		factory->container("analysis", this)->setEnabled(false);
+		factory->container("datapicker", this)->setEnabled(false);
+		factory->container("spreadsheet_toolbar", this)->hide();
 		factory->container("worksheet_toolbar", this)->hide();
 		factory->container("cartesian_plot_toolbar", this)->hide();
-		factory->container("spreadsheet_toolbar", this)->hide();
 		factory->container("datapicker_toolbar", this)->hide();
+#ifdef HAVE_CANTOR_LIBS
+		factory->container("cas_worksheet", this)->setEnabled(false);
+		factory->container("cas_worksheet_toolbar", this)->hide();
+#endif
 		return;
 	}
 
@@ -496,19 +569,24 @@ void MainWin::updateGUI() {
 	if (w!=0) {
 		//enable worksheet related menus
 		factory->container("worksheet", this)->setEnabled(true);
+ 		factory->container("analysis", this)->setEnabled(true);
 // 		factory->container("drawing", this)->setEnabled(true);
 
 		//disable spreadsheet and matrix related menus
 		factory->container("spreadsheet", this)->setEnabled(false);
-// 		factory->container("analysis", this)->setEnabled(false);
 		factory->container("matrix", this)->setEnabled(false);
 
-		//populate worksheet-menu
+		//populate worksheet menu
 		WorksheetView* view=qobject_cast<WorksheetView*>(w->view());
 		QMenu* menu=qobject_cast<QMenu*>(factory->container("worksheet", this));
 		menu->clear();
 		view->createContextMenu(menu);
 
+		//populate analysis menu
+		menu=qobject_cast<QMenu*>(factory->container("analysis", this));
+		menu->clear();
+		view->createAnalysisMenu(menu);
+
 		//populate worksheet-toolbar
 		QToolBar* toolbar=qobject_cast<QToolBar*>(factory->container("worksheet_toolbar", this));
 		if (group.groupList().indexOf("Toolbar worksheet_toolbar")==-1)
@@ -531,7 +609,8 @@ void MainWin::updateGUI() {
 		factory->container("spreadsheet_toolbar", this)->setVisible(false);
 	} else {
 		factory->container("worksheet", this)->setEnabled(false);
-//  	factory->container("drawing", this)->setEnabled(false);
+ 		factory->container("analysis", this)->setEnabled(false);
+//		factory->container("drawing", this)->setEnabled(false);
 		factory->container("worksheet_toolbar", this)->setVisible(false);
 		factory->container("cartesian_plot_toolbar", this)->setVisible(false);
 
@@ -542,7 +621,6 @@ void MainWin::updateGUI() {
 	if (spreadsheet) {
 		//enable spreadsheet related menus
 		factory->container("spreadsheet", this)->setEnabled(true);
-// 		factory->container("analysis", this)->setEnabled(true);
 
 		//populate spreadsheet-menu
 		SpreadsheetView* view=qobject_cast<SpreadsheetView*>(spreadsheet->view());
@@ -561,7 +639,6 @@ void MainWin::updateGUI() {
 	} else {
 		factory->container("spreadsheet", this)->setEnabled(false);
 		factory->container("spreadsheet_toolbar", this)->setVisible(false);
-// 		factory->container("analysis", this)->setEnabled(false);
 	}
 
 	//Handle the Matrix-object
@@ -578,6 +655,26 @@ void MainWin::updateGUI() {
 		factory->container("matrix", this)->setEnabled(false);
 	}
 
+#ifdef HAVE_CANTOR_LIBS
+	CantorWorksheet* cantorworksheet = this->activeCantorWorksheet();
+	if(cantorworksheet) {
+		// enable Cantor Worksheet related menues
+		factory->container("cas_worksheet", this)->setEnabled(true);
+		CantorWorksheetView* view=qobject_cast<CantorWorksheetView*>(cantorworksheet->view());
+		QMenu* menu=qobject_cast<QMenu*>(factory->container("cas_worksheet", this));
+		menu->clear();
+		view->createContextMenu(menu);
+		QToolBar* toolbar=qobject_cast<QToolBar*>(factory->container("cas_worksheet_toolbar", this));
+		toolbar->setVisible(true);
+		toolbar->clear();
+		view->fillToolBar(toolbar);
+	} else {
+		//no cantor worksheet selected -> deactivate cantor worksheet related menu and toolbar
+		factory->container("cas_worksheet", this)->setEnabled(false);
+		factory->container("cas_worksheet_toolbar", this)->setVisible(false);
+	}
+#endif
+
 	const Datapicker* datapicker = this->activeDatapicker();
 	if (datapicker) {
 		factory->container("datapicker", this)->setEnabled(true);
@@ -692,15 +789,15 @@ void MainWin::openProject() {
 	KConfigGroup conf(KSharedConfig::openConfig(), "MainWin");
 	QString dir = conf.readEntry("LastOpenDir", "");
 	QString path = QFileDialog::getOpenFileName(this,i18n("Open project"), dir,
-	               i18n("LabPlot Projects (*.lml *.lml.gz *.lml.bz2 *.LML *.LML.GZ *.LML.BZ2)"));
+	               i18n("LabPlot Projects (*.lml *.lml.gz *.lml.bz2 *.lml.xz *.LML *.LML.GZ *.LML.BZ2 *.LML.XZ)"));
 
 	if (!path.isEmpty()) {
 		this->openProject(path);
 
 		int pos = path.lastIndexOf(QDir::separator());
-		if (pos!=-1) {
+		if (pos != -1) {
 			QString newDir = path.left(pos);
-			if (newDir!=dir)
+			if (newDir != dir)
 				conf.writeEntry("LastOpenDir", newDir);
 		}
 	}
@@ -708,12 +805,17 @@ void MainWin::openProject() {
 
 void MainWin::openProject(const QString& filename) {
 	if (filename == m_currentFileName) {
-		KMessageBox::information(this,
-		                         i18n("The project file %1 is already opened.", filename),i18n("Open project"));
+		KMessageBox::information(this, i18n("The project file %1 is already opened.", filename), i18n("Open project"));
 		return;
 	}
 
-	QIODevice *file = new KCompressionDevice(filename,KFilterDev::compressionTypeForMimeType("application/x-gzip"));
+	QIODevice *file;
+	// first try gzip compression, because older files are gzipped but end with .lml
+	if (filename.endsWith(".lml", Qt::CaseInsensitive))
+		file = new KCompressionDevice(filename,KFilterDev::compressionTypeForMimeType("application/x-gzip"));
+	else	// opens filename using file ending
+		file = new KFilterDev(filename);
+
 	if (file==0)
 		file = new QFile(filename);
 
@@ -803,7 +905,7 @@ bool MainWin::closeProject() {
 	if (m_project==0)
 		return true; //nothing to close
 
-	if(warnModified())
+	if (warnModified())
 		return false;
 
 	delete m_aspectTreeModel;
@@ -830,7 +932,7 @@ bool MainWin::closeProject() {
 
 bool MainWin::saveProject() {
 	const QString& fileName = m_project->fileName();
-	if(fileName.isEmpty())
+	if (fileName.isEmpty())
 		return saveProjectAs();
 	else
 		return save(fileName);
@@ -840,13 +942,13 @@ bool MainWin::saveProjectAs() {
 	KConfigGroup conf(KSharedConfig::openConfig(), "MainWin");
 	QString dir = conf.readEntry("LastOpenDir", "");
 	QString fileName = QFileDialog::getSaveFileName(this, i18n("Save project as"), dir,
-	                   i18n("LabPlot Projects (*.lml *.lml.gz *.lml.bz2 *.LML *.LML.GZ *.LML.BZ2)"));
+	                   i18n("LabPlot Projects (*.lml *.lml.gz *.lml.bz2 *.lml.xz *.LML *.LML.GZ *.LML.BZ2 *.LML.XZ)"));
 
-	if( fileName.isEmpty() )// "Cancel" was clicked
+	if (fileName.isEmpty())// "Cancel" was clicked
 		return false;
 
-	if( fileName.contains(QString(".lml"),Qt::CaseInsensitive) == false )
-		fileName.append(".lml");
+	if (fileName.contains(QLatin1String(".lml"), Qt::CaseInsensitive) == false)
+		fileName.append(QLatin1String(".lml"));
 
 	return save(fileName);
 }
@@ -856,12 +958,13 @@ bool MainWin::saveProjectAs() {
  */
 bool MainWin::save(const QString& fileName) {
 	WAIT_CURSOR;
-	QIODevice* file = new KCompressionDevice(fileName, KFilterDev::compressionTypeForMimeType("application/x-gzip"));
+	// use file ending to find out how to compress file
+	QIODevice* file = new KFilterDev(fileName);
 	if (file == 0)
 		file = new QFile(fileName);
 
 	bool ok;
-	if(file->open(QIODevice::WriteOnly)) {
+	if (file->open(QIODevice::WriteOnly)) {
 		m_project->setFileName(fileName);
 
 		QXmlStreamWriter writer(file);
@@ -917,8 +1020,9 @@ void MainWin::print() {
 		return;
 
 	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-	part->printView();
-	statusBar()->showMessage(i18n("%1 printed", part->name()));
+    if (part->printView()) {
+        statusBar()->showMessage(i18n("%1 printed", part->name()));
+    }
 }
 
 void MainWin::printPreview() {
@@ -927,7 +1031,9 @@ void MainWin::printPreview() {
 		return;
 
 	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-	part->printPreview();
+    if (part->printPreview()) {
+        statusBar()->showMessage(i18n("%1 printed", part->name()));
+    }
 }
 
 /**************************************************************************************/
@@ -936,7 +1042,7 @@ void MainWin::printPreview() {
 	adds a new Folder to the project.
 */
 void MainWin::newFolder() {
-	Folder* folder = new Folder(i18n("Folder %1", 1));
+	Folder* folder = new Folder(i18n("Folder"));
 	this->addAspectToProject(folder);
 }
 
@@ -1005,7 +1111,10 @@ void MainWin::newWorksheet() {
 	this->addAspectToProject(worksheet);
 }
 
-//TODO: void MainWin::newScript(){}
+void MainWin::newNotes() {
+	Note* notes = new Note(i18n("Note"));
+	this->addAspectToProject(notes);
+}
 
 /*!
 	returns a pointer to a Workbook-object, if the currently active Mdi-Subwindow is \a WorkbookView.
@@ -1111,7 +1220,30 @@ Worksheet* MainWin::activeWorksheet() const {
 	return dynamic_cast<Worksheet*>(part);
 }
 
+#ifdef HAVE_CANTOR_LIBS
+/*
+    adds a new Cantor Spreadsheet to the project.
+*/
+void MainWin::newCantorWorksheet(QAction* action) {
+	CantorWorksheet* cantorworksheet = new CantorWorksheet(0, action->data().toString());
+	this->addAspectToProject(cantorworksheet);
+}
+
 /********************************************************************************/
+/*!
+    returns a pointer to a CantorWorksheet-object, if the currently active Mdi-Subwindow is \a CantorWorksheetView
+    Otherwise returns \a 0.
+*/
+CantorWorksheet* MainWin::activeCantorWorksheet() const{
+    QMdiSubWindow* win = m_mdiArea->currentSubWindow();
+    if (!win)
+        return 0;
+
+    AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
+    Q_ASSERT(part);
+    return dynamic_cast<CantorWorksheet*>(part);
+}
+#endif
 
 /*!
 	called if there were changes in the project.
@@ -1182,15 +1314,15 @@ void MainWin::handleAspectAboutToBeRemoved(const AbstractAspect *aspect) {
 }
 
 /*!
-	called when the current aspect in the tree of the project explorer was changed.
-	Selects the new aspect.
+    called when the current aspect in the tree of the project explorer was changed.
+    Selects the new aspect.
 */
 void MainWin::handleCurrentAspectChanged(AbstractAspect *aspect) {
 	if (!aspect)
 		aspect = m_project; // should never happen, just in case
 
 	m_suppressCurrentSubWindowChangedEvent = true;
-	if(aspect->folder() != m_currentFolder)	{
+	if (aspect->folder() != m_currentFolder)	{
 		m_currentFolder = aspect->folder();
 		updateMdiWindowVisibility();
 	}
@@ -1227,7 +1359,10 @@ void MainWin::activateSubWindowForAspect(const AbstractAspect* aspect) const {
 			win = part->mdiSubWindow();
 
 		if (m_mdiArea->subWindowList().indexOf(win) == -1) {
-			m_mdiArea->addSubWindow(win);
+			if (dynamic_cast<const Note*>(part))
+				m_mdiArea->addSubWindow(win, Qt::Tool);
+			else
+				m_mdiArea->addSubWindow(win);
 			win->show();
 		}
 		m_mdiArea->setActiveSubWindow(win);
@@ -1320,7 +1455,7 @@ void MainWin::redo() {
 void MainWin::updateMdiWindowVisibility() const {
 	QList<QMdiSubWindow *> windows = m_mdiArea->subWindowList();
 	PartMdiView * part_view;
-	switch(m_project->mdiWindowVisibility()) {
+	switch (m_project->mdiWindowVisibility()) {
 	case Project::allMdiWindows:
 		foreach(QMdiSubWindow* window, windows)
 			window->show();
@@ -1330,7 +1465,7 @@ void MainWin::updateMdiWindowVisibility() const {
 		foreach(QMdiSubWindow *window, windows) {
 			part_view = qobject_cast<PartMdiView *>(window);
 			Q_ASSERT(part_view);
-			if(part_view->part()->folder() == m_currentFolder)
+			if (part_view->part()->folder() == m_currentFolder)
 				part_view->show();
 			else
 				part_view->hide();
@@ -1339,7 +1474,7 @@ void MainWin::updateMdiWindowVisibility() const {
 	case Project::folderAndSubfolders:
 		foreach(QMdiSubWindow *window, windows) {
 			part_view = qobject_cast<PartMdiView *>(window);
-			if(part_view->part()->isDescendantOf(m_currentFolder))
+			if (part_view->part()->isDescendantOf(m_currentFolder))
 				part_view->show();
 			else
 				part_view->hide();
@@ -1432,7 +1567,7 @@ void MainWin::handleSettingsChanges() {
 /************************************** dialogs ***************************************/
 /***************************************************************************************/
 /*!
-	shows the dialog with the Undo-history.
+  shows the dialog with the Undo-history.
 */
 void MainWin::historyDialog() {
 	if (!m_project->undoStack())
@@ -1454,19 +1589,19 @@ void MainWin::historyDialog() {
 }
 
 /*!
-	Opens the dialog to import data to the selected workbook, spreadsheet or matrix
+  Opens the dialog to import data to the selected workbook, spreadsheet or matrix
 */
 void MainWin::importFileDialog(const QString& fileName) {
 	m_importFileDialog = new ImportFileDialog(this, false, fileName);
 
-	if ( m_currentAspect->inherits("Spreadsheet") || m_currentAspect->inherits("Matrix") || m_currentAspect->inherits("Workbook") ) {
+	if (m_currentAspect->inherits("Spreadsheet") || m_currentAspect->inherits("Matrix") || m_currentAspect->inherits("Workbook")) {
 		m_importFileDialog->setCurrentIndex( m_projectExplorer->currentIndex());
-	} else if ( m_currentAspect->inherits("Column") ) {
+	} else if (m_currentAspect->inherits("Column")) {
 		if (m_currentAspect->parentAspect()->inherits("Spreadsheet"))
 			m_importFileDialog->setCurrentIndex( m_aspectTreeModel->modelIndexOfAspect(m_currentAspect->parentAspect()));
 	}
 
-	if ( m_importFileDialog->exec() == QDialog::Accepted ) {
+	if (m_importFileDialog->exec() == QDialog::Accepted) {
 		m_importFileDialog->importTo(statusBar());
 		m_project->setChanged(true);
 	}
@@ -1476,7 +1611,7 @@ void MainWin::importFileDialog(const QString& fileName) {
 }
 
 /*!
-	opens the dialog for the export of the currently active worksheet, spreadsheet or matrix.
+  opens the dialog for the export of the currently active worksheet, spreadsheet or matrix.
  */
 void MainWin::exportDialog() {
 	QMdiSubWindow* win = m_mdiArea->currentSubWindow();
@@ -1484,16 +1619,17 @@ void MainWin::exportDialog() {
 		return;
 
 	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-	part->exportView();
-	statusBar()->showMessage(i18n("%1 exported", part->name()));
+    if (part->exportView()) {
+        statusBar()->showMessage(i18n("%1 exported", part->name()));
+    }
 }
 
 /*!
-	adds a new file data source to the current project.
+  adds a new file data source to the current project.
 */
 void MainWin::newFileDataSourceActionTriggered() {
 	ImportFileDialog* dlg = new ImportFileDialog(this, true);
-	if ( dlg->exec() == QDialog::Accepted ) {
+	if (dlg->exec() == QDialog::Accepted) {
 		FileDataSource* dataSource = new FileDataSource(0,  i18n("File data source%1", 1));
 		dlg->importToFileDataSource(dataSource, statusBar());
 		this->addAspectToProject(dataSource);
@@ -1502,7 +1638,7 @@ void MainWin::newFileDataSourceActionTriggered() {
 }
 
 /*!
-	adds a new SQL data source to the current project.
+  adds a new SQL data source to the current project.
 */
 void MainWin::newSqlDataSourceActionTriggered() {
 	//TODO
@@ -1510,7 +1646,7 @@ void MainWin::newSqlDataSourceActionTriggered() {
 
 void MainWin::addAspectToProject(AbstractAspect* aspect) {
 	QModelIndex index = m_projectExplorer->currentIndex();
-	if(!index.isValid())
+	if (!index.isValid())
 		m_project->addChild(aspect);
 	else {
 		AbstractAspect * parent_aspect = static_cast<AbstractAspect *>(index.internalPointer());
