@@ -38,7 +38,7 @@
 #include <KLocalizedString>
 #include <KConfigGroup>
 
-#include <math.h>
+#include <cmath>
 
 // a couple of standard sizes in mm, taken from qprinter.cpp
 const int numOfPaperSizes = 30;
@@ -88,12 +88,12 @@ WorksheetDock::WorksheetDock(QWidget *parent): QWidget(parent), m_worksheet(0),
 	//Background-tab
 	ui.cbBackgroundColorStyle->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
 	ui.kleBackgroundFileName->setClearButtonShown(true);
-    ui.bOpen->setIcon( QIcon::fromTheme("document-open") );
+	ui.bOpen->setIcon( QIcon::fromTheme("document-open") );
 
 	ui.kleBackgroundFileName->setCompletionObject(m_completion);
 
 	//adjust layouts in the tabs
-	for (int i=0; i<ui.tabWidget->count(); ++i){
+	for (int i=0; i<ui.tabWidget->count(); ++i) {
 		QGridLayout* layout = dynamic_cast<QGridLayout*>(ui.tabWidget->widget(i)->layout());
 		if (!layout)
 			continue;
@@ -150,13 +150,13 @@ WorksheetDock::~WorksheetDock() {
 	delete m_completion;
 }
 
-void WorksheetDock::setWorksheets(QList<Worksheet*> list){
+void WorksheetDock::setWorksheets(QList<Worksheet*> list) {
 	m_initializing = true;
 	m_worksheetList = list;
 	m_worksheet = list.first();
 
 	//if there are more then one worksheet in the list, disable the name and comment field in the tab "general"
-	if (list.size()==1){
+	if (list.size()==1) {
 		ui.lName->setEnabled(true);
 		ui.leName->setEnabled(true);
 		ui.lComment->setEnabled(true);
@@ -208,7 +208,7 @@ void WorksheetDock::setWorksheets(QList<Worksheet*> list){
 	Checks whether the size is one of the QPrinter::PaperSize and
 	updates Size and Orientation checkbox when width/height changes.
 */
-void WorksheetDock::updatePaperSize(){
+void WorksheetDock::updatePaperSize() {
 	if (m_worksheet->useViewSize()) {
 		ui.cbSize->setCurrentIndex(0);
 		return;
@@ -221,7 +221,7 @@ void WorksheetDock::updatePaperSize(){
 	float h=(float)ui.sbHeight->value()*10;
 
 	//check the portrait-orientation first
-	while ( i<numOfPaperSizes && !(w==qt_paperSizes[i][0] && h==qt_paperSizes[i][1]) ){
+	while ( i<numOfPaperSizes && !(w==qt_paperSizes[i][0] && h==qt_paperSizes[i][1]) ) {
 		i++;
 	}
 
@@ -230,7 +230,7 @@ void WorksheetDock::updatePaperSize(){
 	}else{
 		//check for the landscape-orientation
 		i=0;
-		while ( i<numOfPaperSizes && !(w==qt_paperSizes[i][1] && h==qt_paperSizes[i][0]) ){
+		while ( i<numOfPaperSizes && !(w==qt_paperSizes[i][1] && h==qt_paperSizes[i][0]) ) {
 			i++;
 		}
 
@@ -239,8 +239,8 @@ void WorksheetDock::updatePaperSize(){
 	}
 
 	//determine the position of the QPrinter::PaperSize in the combobox
-	for (int index=0; index<numOfPaperSizes+1; index++){
-		if (ui.cbSize->itemData(index+2).toInt() == i){
+	for (int index=0; index<numOfPaperSizes+1; index++) {
+		if (ui.cbSize->itemData(index+2).toInt() == i) {
 			ui.cbSize->setCurrentIndex(index+2);
 			break;
 		}
@@ -250,7 +250,7 @@ void WorksheetDock::updatePaperSize(){
 //*************************************************************
 //****** SLOTs for changes triggered in WorksheetDock *********
 //*************************************************************
-void WorksheetDock::retranslateUi(){
+void WorksheetDock::retranslateUi() {
 	m_initializing = true;
 
 	//Geometry
@@ -320,21 +320,21 @@ void WorksheetDock::retranslateUi(){
 }
 
 // "General"-tab
-void WorksheetDock::nameChanged(){
+void WorksheetDock::nameChanged() {
   if (m_initializing)
 	return;
 
   m_worksheet->setName(ui.leName->text());
 }
 
-void WorksheetDock::commentChanged(){
+void WorksheetDock::commentChanged() {
   if (m_initializing)
 	return;
 
   m_worksheet->setComment(ui.leComment->text());
 }
 
-void WorksheetDock::scaleContentChanged(bool scaled){
+void WorksheetDock::scaleContentChanged(bool scaled) {
 	if (m_initializing)
 		return;
 
@@ -342,10 +342,10 @@ void WorksheetDock::scaleContentChanged(bool scaled){
 		worksheet->setScaleContent(scaled);
 }
 
-void WorksheetDock::sizeChanged(int i){
+void WorksheetDock::sizeChanged(int i) {
 	int index = ui.cbSize->itemData(i).toInt();
 
-	if (index==QPrinter::Custom){
+	if (index==QPrinter::Custom) {
 		ui.sbWidth->setEnabled(true);
 		ui.sbHeight->setEnabled(true);
 		ui.lOrientation->hide();
@@ -378,7 +378,7 @@ void WorksheetDock::sizeChanged(int i){
 	} else {
 		//determine the width and the height of the to be used predefined layout
 		float w, h;
-		if (ui.cbOrientation->currentIndex() == 0){
+		if (ui.cbOrientation->currentIndex() == 0) {
 			w=qt_paperSizes[index][0];
 			h=qt_paperSizes[index][1];
 		}else{
@@ -401,7 +401,7 @@ void WorksheetDock::sizeChanged(int i){
 	}
 }
 
-void WorksheetDock::sizeChanged(){
+void WorksheetDock::sizeChanged() {
 	if (m_initializing)
 		return;
 
@@ -411,7 +411,7 @@ void WorksheetDock::sizeChanged(){
 		worksheet->setPageRect(QRect(0,0,w,h));
 }
 
-void WorksheetDock::orientationChanged(int index){
+void WorksheetDock::orientationChanged(int index) {
 	Q_UNUSED(index);
 	if (m_initializing)
 		return;
@@ -420,10 +420,10 @@ void WorksheetDock::orientationChanged(int index){
 }
 
 // "Background"-tab
-void WorksheetDock::backgroundTypeChanged(int index){
+void WorksheetDock::backgroundTypeChanged(int index) {
 	PlotArea::BackgroundType type = (PlotArea::BackgroundType)index;
 
-	if (type == PlotArea::Color){
+	if (type == PlotArea::Color) {
 		ui.lBackgroundColorStyle->show();
 		ui.cbBackgroundColorStyle->show();
 		ui.lBackgroundImageStyle->hide();
@@ -440,7 +440,7 @@ void WorksheetDock::backgroundTypeChanged(int index){
 
 		PlotArea::BackgroundColorStyle style =
 			(PlotArea::BackgroundColorStyle) ui.cbBackgroundColorStyle->currentIndex();
-		if (style == PlotArea::SingleColor){
+		if (style == PlotArea::SingleColor) {
 			ui.lBackgroundFirstColor->setText(i18n("Color"));
 			ui.lBackgroundSecondColor->hide();
 			ui.kcbBackgroundSecondColor->hide();
@@ -449,7 +449,7 @@ void WorksheetDock::backgroundTypeChanged(int index){
 			ui.lBackgroundSecondColor->show();
 			ui.kcbBackgroundSecondColor->show();
 		}
-	}else if(type == PlotArea::Image){
+	}else if (type == PlotArea::Image) {
 		ui.lBackgroundFirstColor->hide();
 		ui.kcbBackgroundFirstColor->hide();
 		ui.lBackgroundSecondColor->hide();
@@ -464,7 +464,7 @@ void WorksheetDock::backgroundTypeChanged(int index){
 		ui.lBackgroundFileName->show();
 		ui.kleBackgroundFileName->show();
 		ui.bOpen->show();
-	}else if(type == PlotArea::Pattern){
+	}else if (type == PlotArea::Pattern) {
 		ui.lBackgroundFirstColor->setText(i18n("Color"));
 		ui.lBackgroundFirstColor->show();
 		ui.kcbBackgroundFirstColor->show();
@@ -485,15 +485,15 @@ void WorksheetDock::backgroundTypeChanged(int index){
 	if (m_initializing)
 		return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setBackgroundType(type);
   }
 }
 
-void WorksheetDock::backgroundColorStyleChanged(int index){
+void WorksheetDock::backgroundColorStyleChanged(int index) {
 	PlotArea::BackgroundColorStyle style = (PlotArea::BackgroundColorStyle)index;
 
-	if (style == PlotArea::SingleColor){
+	if (style == PlotArea::SingleColor) {
 		ui.lBackgroundFirstColor->setText(i18n("Color"));
 		ui.lBackgroundSecondColor->hide();
 		ui.kcbBackgroundSecondColor->hide();
@@ -518,45 +518,45 @@ void WorksheetDock::backgroundColorStyleChanged(int index){
 	}
 }
 
-void WorksheetDock::backgroundImageStyleChanged(int index){
+void WorksheetDock::backgroundImageStyleChanged(int index) {
 	if (m_initializing)
 		return;
 
 	PlotArea::BackgroundImageStyle style = (PlotArea::BackgroundImageStyle)index;
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setBackgroundImageStyle(style);
 	}
 }
 
-void WorksheetDock::backgroundBrushStyleChanged(int index){
+void WorksheetDock::backgroundBrushStyleChanged(int index) {
 	if (m_initializing)
 		return;
 
 	Qt::BrushStyle style = (Qt::BrushStyle)index;
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setBackgroundBrushStyle(style);
 	}
 }
 
-void WorksheetDock::backgroundFirstColorChanged(const QColor& c){
+void WorksheetDock::backgroundFirstColorChanged(const QColor& c) {
   if (m_initializing)
 	return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setBackgroundFirstColor(c);
 	}
 }
 
-void WorksheetDock::backgroundSecondColorChanged(const QColor& c){
+void WorksheetDock::backgroundSecondColorChanged(const QColor& c) {
   if (m_initializing)
 	return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setBackgroundSecondColor(c);
 	}
 }
 
-void WorksheetDock::backgroundOpacityChanged(int value){
+void WorksheetDock::backgroundOpacityChanged(int value) {
   	if (m_initializing)
 		return;
 
@@ -566,74 +566,74 @@ void WorksheetDock::backgroundOpacityChanged(int value){
 }
 
 //"Layout"-tab
-void WorksheetDock::layoutTopMarginChanged(double margin){
+void WorksheetDock::layoutTopMarginChanged(double margin) {
 	if (m_initializing)
 		return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setLayoutTopMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
 	}
 }
 
-void WorksheetDock::layoutBottomMarginChanged(double margin){
+void WorksheetDock::layoutBottomMarginChanged(double margin) {
 	if (m_initializing)
 		return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setLayoutBottomMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
 	}
 }
 
-void WorksheetDock::layoutLeftMarginChanged(double margin){
+void WorksheetDock::layoutLeftMarginChanged(double margin) {
 	if (m_initializing)
 		return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setLayoutLeftMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
 	}
 }
 
-void WorksheetDock::layoutRightMarginChanged(double margin){
+void WorksheetDock::layoutRightMarginChanged(double margin) {
 	if (m_initializing)
 		return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setLayoutRightMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
 	}
 }
 
-void WorksheetDock::layoutHorizontalSpacingChanged(double spacing){
+void WorksheetDock::layoutHorizontalSpacingChanged(double spacing) {
 	if (m_initializing)
 		return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setLayoutHorizontalSpacing(Worksheet::convertToSceneUnits(spacing, Worksheet::Centimeter));
 	}
 }
 
-void WorksheetDock::layoutVerticalSpacingChanged(double spacing){
+void WorksheetDock::layoutVerticalSpacingChanged(double spacing) {
 	if (m_initializing)
 		return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setLayoutVerticalSpacing(Worksheet::convertToSceneUnits(spacing, Worksheet::Centimeter));
 	}
 }
 
-void WorksheetDock::layoutRowCountChanged(int count){
+void WorksheetDock::layoutRowCountChanged(int count) {
 	if (m_initializing)
 		return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setLayoutRowCount(count);
 	}
 }
 
-void WorksheetDock::layoutColumnCountChanged(int count){
+void WorksheetDock::layoutColumnCountChanged(int count) {
 	if (m_initializing)
 		return;
 
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setLayoutColumnCount(count);
 	}
 }
@@ -652,8 +652,8 @@ void WorksheetDock::selectFile() {
 	}
 
 	QString path = QFileDialog::getOpenFileName(this, i18n("Select the image file"), dir, i18n("Images (%1)", formats));
-    if (path.isEmpty())
-        return; //cancel was clicked in the file-dialog
+	if (path.isEmpty())
+		return; //cancel was clicked in the file-dialog
 
 	int pos = path.lastIndexOf(QDir::separator());
 	if (pos!=-1) {
@@ -662,20 +662,20 @@ void WorksheetDock::selectFile() {
 			conf.writeEntry("LastImageDir", newDir);
 	}
 
-    ui.kleBackgroundFileName->setText( path );
+	ui.kleBackgroundFileName->setText( path );
 
 	foreach(Worksheet* worksheet, m_worksheetList)
 		worksheet->setBackgroundFileName(path);
 }
 
-void WorksheetDock::fileNameChanged(){
+void WorksheetDock::fileNameChanged() {
 	if (m_initializing)
 		return;
 
 	QString fileName = ui.kleBackgroundFileName->text();
-	foreach(Worksheet* worksheet, m_worksheetList){
+	foreach(Worksheet* worksheet, m_worksheetList) {
 		worksheet->setBackgroundFileName(fileName);
-  }
+	}
 }
 
 //*************************************************************
@@ -834,7 +834,7 @@ void WorksheetDock::worksheetLayoutColumnCountChanged(int value) {
 //*************************************************************
 //******************** SETTINGS *******************************
 //*************************************************************
-void WorksheetDock::load(){
+void WorksheetDock::load() {
 	// Geometry
 	ui.chScaleContent->setChecked(m_worksheet->scaleContent());
 	ui.sbWidth->setValue(Worksheet::convertFromSceneUnits( m_worksheet->pageRect().width(), Worksheet::Centimeter) );
@@ -882,7 +882,7 @@ void WorksheetDock::loadConfigFromTemplate(KConfig& config) {
 	m_worksheet->endMacro();
 }
 
-void WorksheetDock::loadConfig(KConfig& config){
+void WorksheetDock::loadConfig(KConfig& config) {
 	KConfigGroup group = config.group( "Worksheet" );
 
 	// Geometry
