@@ -1,5 +1,5 @@
 /***************************************************************************
-    File             : XYFitCurveDock.h
+    File             : XYFitCurveDock.cpp
     Project          : LabPlot
     --------------------------------------------------------------------
     Copyright        : (C) 2014-2016 Alexander Semke (alexander.semke@web.de)
@@ -29,7 +29,6 @@
 #include "XYFitCurveDock.h"
 #include "backend/core/AspectTreeModel.h"
 #include "backend/core/Project.h"
-#include "backend/worksheet/plots/cartesian/XYFitCurve.h"
 #include "commonfrontend/widgets/TreeViewComboBox.h"
 #include "kdefrontend/widgets/ConstantsWidget.h"
 #include "kdefrontend/widgets/FunctionsWidget.h"
@@ -38,7 +37,7 @@
 
 #include <QMenu>
 #include <QWidgetAction>
-#include <KLocalizedString>
+
 /*!
   \class XYFitCurveDock
   \brief  Provides a widget for editing the properties of the XYFitCurves
@@ -53,12 +52,11 @@
   \ingroup kdefrontend
 */
 
-XYFitCurveDock::XYFitCurveDock(QWidget *parent): XYCurveDock(parent),
-	cbXDataColumn(0),
-	cbYDataColumn(0),
-	cbWeightsColumn(0),
-	m_fitCurve(0) {
+XYFitCurveDock::XYFitCurveDock(QWidget *parent)
+	 : XYCurveDock(parent), cbXDataColumn(0), cbYDataColumn(0), cbWeightsColumn(0), m_fitCurve(0) {
 
+	//remove the tab "Error bars"
+	ui.tabWidget->removeTab(5);
 }
 
 /*!
@@ -91,6 +89,7 @@ void XYFitCurveDock::setupGeneral() {
 	uiGeneralTab.cbModel->addItem(i18n("Gaussian"));
 	uiGeneralTab.cbModel->addItem(i18n("Lorentz (Cauchy)"));
 	uiGeneralTab.cbModel->addItem(i18n("Maxwell-Boltzmann"));
+	uiGeneralTab.cbModel->addItem(i18n("Sigmoid"));
 	uiGeneralTab.cbModel->addItem(i18n("Custom"));
 
 	uiGeneralTab.teEquation->setMaximumHeight(uiGeneralTab.leName->sizeHint().height()*2);
@@ -168,7 +167,7 @@ void XYFitCurveDock::initGeneralTab() {
 
 void XYFitCurveDock::setModel() {
 	QList<const char*>  list;
-	list<<"Folder"<<"Workbook"<<"Spreadsheet"<<"FileDataSource"<<"Column"<<"Datapicker";
+	list<<"Folder"<<"Workbook"<<"Spreadsheet"<<"FileDataSource"<<"Column"<<"CantorWorksheet"<<"Datapicker";
 	cbXDataColumn->setTopLevelClasses(list);
 	cbYDataColumn->setTopLevelClasses(list);
 	cbWeightsColumn->setTopLevelClasses(list);
@@ -300,7 +299,11 @@ void XYFitCurveDock::modelChanged(int index) {
 		uiGeneralTab.sbDegree->setVisible(true);
 		uiGeneralTab.sbDegree->setMaximum(10);
 		uiGeneralTab.sbDegree->setValue(1);
-	} else if (type == XYFitCurve::Lorentz || type == XYFitCurve::Maxwell || type == XYFitCurve::Inverse_Exponential || type == XYFitCurve::Custom) {
+	} else if (type == XYFitCurve::Lorentz
+		|| type == XYFitCurve::Maxwell
+		|| type == XYFitCurve::Inverse_Exponential
+		|| type == XYFitCurve::Sigmoid
+		|| type == XYFitCurve::Custom) {
 		uiGeneralTab.lDegree->setVisible(false);
 		uiGeneralTab.sbDegree->setVisible(false);
 	}
@@ -423,7 +426,12 @@ void XYFitCurveDock::updateModelEquation() {
 		m_fitData.model = eq;
 		vars << "a";
 		m_fitData.paramNames << "a";
-	} else if (m_fitData.modelType==XYFitCurve::Custom) {
+	} else if (m_fitData.modelType == XYFitCurve::Sigmoid) {
+		eq = "a/(1+exp(-b*(x-c)))";
+		m_fitData.model = eq;
+		vars << "a" << "b" << "c";
+		m_fitData.paramNames << "a" << "b" << "c";
+	} else if (m_fitData.modelType == XYFitCurve::Custom) {
 		//use the equation of the last selected predefined model or of the last available custom model
 		eq = m_fitData.model;
 		vars << m_fitData.paramNames;
@@ -562,40 +570,40 @@ void XYFitCurveDock::showFitResult() {
 	}
 
 	const XYFitCurve::FitData& fitData = m_fitCurve->fitData();
-	QString str = i18n("status") + ": " + fitResult.status + "<br>";
+	QString str = i18n("status:") + ' ' + fitResult.status + "<br>";
 
 	if (!fitResult.valid) {
 		uiGeneralTab.teResult->setText(str);
 		return; //result is not valid, there was an error which is shown in the status-string, nothing to show more.
 	}
 
-	str += i18n("iterations") + ": " + QString::number(fitResult.iterations) + "<br>";
+	str += i18n("iterations:") + ' ' + QString::number(fitResult.iterations) + "<br>";
 	if (fitResult.elapsedTime>1000)
 		str += i18n("calculation time: %1 s", fitResult.elapsedTime/1000) + "<br>";
 	else
 		str += i18n("calculation time: %1 ms", fitResult.elapsedTime) + "<br>";
 
-	str += i18n("degrees of freedom") + ": " + QString::number(fitResult.dof) + "<br><br>";
+	str += i18n("degrees of freedom:") + ' ' + QString::number(fitResult.dof) + "<br><br>";
 
-	str += "<b>Parameters:</b>";
+	str += "<b>" +i18n("Parameters:") + "</b>";
 	for (int i=0; i<fitResult.paramValues.size(); i++) {
 		str += "<br>" + fitData.paramNames.at(i) + QString(" = ") + QString::number(fitResult.paramValues.at(i))
 		       + QString::fromUtf8("\u2213") + QString::number(fitResult.errorValues.at(i));
 	}
 
-	str += "<br><br><b>Goodness of fit:</b><br>";
-	str += i18n("sum of squared errors") + ": " + QString::number(fitResult.sse) + "<br>";
-	str += i18n("mean squared error") + ": " + QString::number(fitResult.mse) + "<br>";
-	str += i18n("root-mean squared error") + ": " + QString::number(fitResult.rmse) + "<br>";
-	str += i18n("mean absolute error") + ": " + QString::number(fitResult.mae) + "<br>";
+	str += "<br><br><b>" + i18n("Goodness of fit:") + "</b><br>";
+	str += i18n("sum of squared errors:") + ' ' + QString::number(fitResult.sse) + "<br>";
+	str += i18n("mean squared error:") + ' ' + QString::number(fitResult.mse) + "<br>";
+	str += i18n("root-mean squared error:") + ' ' + QString::number(fitResult.rmse) + "<br>";
+	str += i18n("mean absolute error:") + ' ' + QString::number(fitResult.mae) + "<br>";
 
 	if (fitResult.dof!=0) {
-		str += i18n("residual mean square") + ": " + QString::number(fitResult.rms) + "<br>";
-		str += i18n("residual standard deviation") + ": " + QString::number(fitResult.rsd) + "<br>";
+		str += i18n("residual mean square:") + ' ' + QString::number(fitResult.rms) + "<br>";
+		str += i18n("residual standard deviation:") + ' ' + QString::number(fitResult.rsd) + "<br>";
 	}
 
-	str += i18n("coefficient of determination (R²)") + ": " + QString::number(fitResult.rsquared) + "<br>";
-	str += i18n("adj. coefficient of determination (R²)") + ": " + QString::number(fitResult.rsquaredAdj) + "<br>";
+	str += i18n("coefficient of determination (R²):") + ' ' + QString::number(fitResult.rsquared) + "<br>";
+	str += i18n("adj. coefficient of determination (R²):") + ' ' + QString::number(fitResult.rsquaredAdj) + "<br>";
 // 	str += "<br><br>";
 //
 // 	QStringList iterations = fitResult.solverOutput.split(';');
